==> comphep_33.23.tar.gz: comphep_33.23/c_source/symb/lbl.c <==
/*
 Copyright (C) 1997, Alexander Pukhov, e-mail: pukhov@theory.npi.msu.su 
*/
#include"chep_crt.h"
#include "syst2.h"
#include "lbl.h"
#include "os.h"
#include "s_files.h"

void  cheplabel(void)
{
 int  key; 
 char fname[STRSIZ];
 FILE *f;
 
 while(1)
 {
   goto_xy(20,2);  print("Skobeltsyn Institute of Nuclear Physics");
   goto_xy(28,3);  print("Moscow State University");

   goto_xy(22,5); print("%s(22.6.2000)",version);
   goto_xy(15,6); print("a package for computation in high energy physics");
   
   goto_xy(25,9);print("Copyright (C) 1997,1999,  AUTHORS:");
   goto_xy(15,10);print("A.Pukhov, E.Boos, M.Dubinin, V.Edneral, V.Ilyin,");
   goto_xy(15,11);print("D.Kovalenko, A.Kryukov, V.Savrin, S.Shichanin, A.Semenov");

   goto_xy(25,13); print("According to the license agreement");
   goto_xy(15,14); print("publications which result from using the program should");
   goto_xy(15,15); print("contain a reference to the article describing CompHEP."); 

   goto_xy(25,17); print("Click the field below to get");
          chepbox(19,18,39,20); chepbox(41,18,61,20);
   scrcolor(Blue,LightGray);  
   goto_xy(21,19 ); print("License Agreement"); 
   goto_xy(46,19); print("References");
   scrcolor(Black,LightGray);
    
   goto_xy(1,22); print("For contacts:");
   goto_xy(1,23); print("Slava Ilyin     <ilyin@theory.npi.msu.su>");
   goto_xy(1,24); print("Alexander Pukhov<pukhov@theory.npi.msu.su>");

   goto_xy(47,22); print("WWW pages:");
   goto_xy(47,23); print("http://theory.npi.msu.su/comphep");
   goto_xy(47,24); print("http://www.ifh.de/~pukhov");

   clearTypeAhead();
   key= inkey();
   if(key==KB_MOUSE &&  mouse_info.row==19 &&
    mouse_info.col >19 &&  mouse_info.col<61)
   { if(mouse_info.col<39)  
     { sprintf(fname,"%s%cLicence.txt",pathtocomphep,f_slash);
       f=fopen(fname,"r");
       showtext (5, 1, 75,1,"",f); 
       fclose(f);
     }
     else if(mouse_info.col>41) 
     { 
       sprintf(fname,"%s%cReference.txt",pathtocomphep,f_slash);
       f=fopen(fname,"r");
       showtext (5, 1, 75,1,"",f);
       fclose(f);
    } else break;
   }else break;
 }
 clr_scr(FGmain,BGmain);
}

==> comphep_41.10.tar.gz: comphep_41.10/c_source/symb/lbl.c <==
/*
 Copyright (C) 2000, Alexander Pukhov, e-mail: pukhov@theory.npi.msu.su 
*/
#include"chep_crt.h"
#include "syst2.h"
#include "lbl.h"
#include "os.h"
#include "s_files.h"

void  cheplabel(void)
{
 int  key; 
 char fname[STRSIZ];
 FILE *f;
 
 while(1)
 {
   goto_xy(20,2);  print("Skobeltsyn Institute of Nuclear Physics");
   goto_xy(28,3);  print("Moscow State University");

   goto_xy(22,5); print("%s(30.10.2000)",version);
   goto_xy(15,6); print("a package for computation in high energy physics");

scrcolor(Blue,LightGray);
   goto_xy(20,7); print("Preliminary release. Do not distribute it.");
scrcolor(FGmain,BGmain);
   
  goto_xy(25,9);print("Copyright (C) 1997,1999,  AUTHORS:");
  goto_xy(15,10);print("A.Pukhov, E.Boos, M.Dubinin, V.Edneral, V.Ilyin,");
  goto_xy(15,11);print("D.Kovalenko, A.Kryukov, V.Savrin, S.Shichanin, A.Semenov");


   goto_xy(25,13); print("According to the license agreement");
   goto_xy(15,14); print("publications which result from using the program should");
   goto_xy(15,15); print("contain a reference to the article describing CompHEP."); 

   goto_xy(25,17); print("Click the field below to get");
          chepbox(19,18,39,20); chepbox(41,18,61,20);
   scrcolor(Blue,LightGray);  
   goto_xy(21,19 ); print("License Agreement"); 
   goto_xy(46,19); print("References");
   scrcolor(Black,LightGray);
    
   goto_xy(1,22); print("For contacts:");
   goto_xy(1,23); print("Alexander Pukhov<pukhov@theory.npi.msu.su>");

   goto_xy(47,22); print("WWW pages:");
   goto_xy(47,23); print("http://theory.npi.msu.su/~comphep");
   goto_xy(47,24); print("http://www.ifh.de/~pukhov");

   clearTypeAhead();
   key= inkey();
   if(key==KB_MOUSE &&  mouse_info.row==19 &&
    mouse_info.col >19 &&  mouse_info.col<61)
   { if(mouse_info.col<39)  
     { sprintf(fname,"%s%cLicence.txt",pathtocomphep,f_slash);
       f=fopen(fname,"r");
       showtext (5, 1, 75,1,"",f); 
       fclose(f);
     }
     else if(mouse_info.col>41) 
     { 
       sprintf(fname,"%s%cReference.txt",pathtocomphep,f_slash);
       f=fopen(fname,"r");
       showtext (5, 1, 75,1,"",f);
       fclose(f);
    } else break;
   }else break;
 }
 clr_scr(FGmain,BGmain);
}
